Setup
=====

The Adversarial Robustness Toolbox is designed to run with Python 3 and Python 2.

Installation with `pip`
-----------------------

The library can be installed from the PyPi repository using `pip`:

.. code-block:: bash

   pip install adversarial-robustness-toolbox

Manual installation
-------------------

For the most recent version of the library, either download the source code or clone the repository in your directory of choice:

.. code-block:: bash

   git clone https://github.com/IBM/adversarial-robustness-toolbox

To install ART, do the following in the project folder:

.. code-block:: bash

   pip install .

The library comes with a basic set of unit tests.
To check your install, you can run all the unit tests by calling in the library folder:

.. code-block:: bash

   bash run_tests.sh
